#! /usr/bin/env python
import re
import sys

from scrib import barf

if sys.version_info[0] >= 3:
	xrange = range
	unicode = str
	basestring = str


class Clean:
	def __init__(self, debug):
		self.debug = debug
		self.chain_length = 2
		self.stop_word = '!S!'
		self.barf = barf.Barf
	
	def sanitize(self, message):
		"""
		Sanitize the data.
		"""
		if self.debug is 1:
			self.barf('DBG', 'Sanitizing %s ' % message)
		things = [
			'://',
			'\"\'',
			"([a-zA-Z0-9\-_]+?\.)*[a-zA-Z0-9\-_]+?\.[a-zA-Z]{2,5}(\/[a-zA-Z0-9]*)*",
		]
		if self.debug is 1:
			self.barf('DBG', 'Checking for URIs, quotes, and other stuff...')
		for thing in things:
			ret = re.sub(thing, '', message)
		
		ret = ret.replace("\n", " ")
		ret = ret.replace("\r", " ")
		"""
		index = 0
		try:
			while 1:
				index = ret.index("(", ret)
				# Remove matching ) bracket
				i = ret.index(")", index + 1)
				ret = ret[0:i] + ret[i + 1:]
				# And remove the (
				ret = ret[0:index] + ret[index + 1:]
		except ValueError:
			pass
		"""
		if self.debug is 1:
			self.barf('DBG', 'Scanning for mIRC control codes...')
		# Strips out mIRC Control codes
		ccstrip = re.compile(
			"\x1f|\x02|\x12|\x0f|\x16|\x03(?:\d{1,2}(?:,\d{1,2})?)?",
			re.UNICODE
		)
		ret = ccstrip.sub("", ret)

		if self.debug is 1:
			self.barf('DBG', 'Scanning for emoticons...')
		# Emotifacethings
		ret = ret.replace(": ", " : ")
		ret = ret.replace("; ", " ; ")
		# ^--- because some : and ; might be smileys...
		ret = ret.replace("`", "'")

		ret = ret.replace("?", " ? ")
		ret = ret.replace("!", " ! ")
		ret = ret.replace(".", " . ")
		ret = ret.replace(",", " , ")

		# Fixes broken emoticons...
		ret = ret.replace("^ . ^", "^.^")
		ret = ret.replace("- . -", "-.-")
		ret = ret.replace("O . o", "O.o")
		ret = ret.replace("o . O", "o.O")
		ret = ret.replace("o . o", "o.o")
		ret = ret.replace("O . O", "O.O")
		ret = ret.replace("< . <", "<.<")
		ret = ret.replace("> . >", ">.>")
		ret = ret.replace("> . <", ">.<")
		ret = ret.replace(": ?", ":?")
		ret = ret.replace(":- ?", ":-?")
		ret = ret.replace(", , l , ,", ",,l,,")
		ret = ret.replace("@ . @", "@.@")
		ret = ret.replace("D :", "D:")
		ret = ret.replace("c :", "c:")
		ret = ret.replace("C :", "C:")

		"""
		words = ret.split()
		for x in xrange(0, len(words)):
			#is there aliases ?
			for z in self.settings.aliases.keys():
				if self.settings.debug == 1:
					self.barf('DBG', 'Is %s in keys?')
				for alias in self.settings.aliases[z]:
					pattern = "^%s$" % alias
					if re.search(pattern, words[x]):
						if self.settings.debug == 1:
							self.barf('DBG', 'Checking if %s is in %s' % ( z, words[x] ))
						words[x] = z

		ret = " ".join(words)
		if self.settings.debug == 1:
			self.barf('DBG', 'Cleaned messages is of type: %s' % type(message))
		"""
		if ret is not None or ret is not 'None' or ret is not '':
			return ret

	def split(self, message):
		"""
		Split message into word list!
		"""
		words = message.split()
		if len(words) > self.chain_length:
			words.append(self.stop_word)
			for i in range(len(words) - self.chain_length):
				yield words[i:i + self.chain_length + 1]
